"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _gateway = require("@apollo/gateway");

var _apolloServerLambda = require("apollo-server-lambda");

var _buildHeaders = _interopRequireDefault(require("./buildHeaders"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function toBool(value) {
  if (typeof value === "string") {
    return value === "true";
  }

  return Boolean(value);
}

var _default = ({
  server = {},
  handler = {},
  services = []
} = {}) => ({
  name: "create-apollo-gateway",
  type: "create-apollo-gateway",

  async createGateway({
    plugins
  }) {
    const gateway = new _gateway.ApolloGateway({
      serviceList: services,

      buildService({
        url
      }) {
        return new _gateway.RemoteGraphQLDataSource({
          url,

          willSendRequest({
            request,
            context
          }) {
            if (context.headers) {
              Object.keys(context.headers).forEach(key => {
                if (context.headers[key]) {
                  request.http.headers.set(key, context.headers[key]);
                }
              });
            }
          }

        });
      }

    });
    const {
      schema,
      executor
    } = await gateway.load();
    let apollo = new _apolloServerLambda.ApolloServer({
      schema,
      executor,
      introspection: toBool(server.introspection),
      playground: toBool(server.playground),
      context: async ({
        event
      }) => {
        const headers = (0, _buildHeaders.default)(event);
        const headerPlugins = plugins.byType("apollo-gateway-headers");
        headerPlugins.forEach(pl => pl.buildHeaders({
          headers,
          plugins
        }));
        return {
          headers
        };
      }
    });
    return apollo.createHandler({
      cors: {
        origin: "*",
        methods: "GET,HEAD,POST,OPTIONS",
        ...handler.cors
      }
    });
  }

});

exports.default = _default;
//# sourceMappingURL=index.js.map